==> ejc-bfyjerp-api-3.0.0-20250304.033927-169-sources.jar: com/ejianc/business/oa/vo/PayrollDetailVO.java <==
package com.ejianc.business.oa.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 人力行政-工资表子表
 * 
 * @author generator
 * 
 */
public class PayrollDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long payrollId; // 工资表主表id
    private Long deptId; // 部门ID
    private String deptName; // 部门
    private Long postId; // 岗位ID
    private String postName; // 岗位
    private Long sourceId; // 来源id
    private Long employeeId; // 员工名称
    private String name; // 姓名
    private String idCard; // 身份证号
    private BigDecimal salaryTime; // 计薪工时
    private BigDecimal basicSalary; // 基本薪资
    private BigDecimal postSalary; // 岗位薪资
    private BigDecimal levelSalary; // 层级薪资
    private BigDecimal educatedSalary; // 学历津贴
    private BigDecimal sportSalary; // 交通补助
    private BigDecimal yearSalary; // 司龄津贴
    private BigDecimal attendanceDeduct; // 考勤扣款
    private BigDecimal otherPayMny; // 其他应付款
    private BigDecimal otherDeductMny; // 其他扣款
    private BigDecimal salaryMny; // 应发工资
    private BigDecimal actualSalaryMny; // 实发工资
    private BigDecimal endownmentPersonPercent; // 养老保险
    private BigDecimal unemployeePersonMny; // 失业保险
    private BigDecimal baseMedicalPersonMny; // 基本医疗
    private Integer rank; // 职级
    private String rankName; // 职级
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date intoDate; // 入职日期
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date formalDate; // 转正日期
    @JsonFormat(pattern = "yyyy-MM", timezone = "GMT+8")
    private Date payrollDate; // 工资单日期
    private String detailMemo; // 备注
    

    public Long getPayrollId() {
        return payrollId;
    }

    public void setPayrollId(Long payrollId) {
        this.payrollId = payrollId;
    }
    public Long getDeptId() {
        return deptId;
    }

    public void setDeptId(Long deptId) {
        this.deptId = deptId;
    }
    public String getDeptName() {
        return deptName;
    }

    public void setDeptName(String deptName) {
        this.deptName = deptName;
    }
    public Long getPostId() {
        return postId;
    }

    public void setPostId(Long postId) {
        this.postId = postId;
    }
    public String getPostName() {
        return postName;
    }

    public void setPostName(String postName) {
        this.postName = postName;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }
    public BigDecimal getSalaryTime() {
        return salaryTime;
    }

    public void setSalaryTime(BigDecimal salaryTime) {
        this.salaryTime = salaryTime;
    }
    public BigDecimal getBasicSalary() {
        return basicSalary;
    }

    public void setBasicSalary(BigDecimal basicSalary) {
        this.basicSalary = basicSalary;
    }
    public BigDecimal getPostSalary() {
        return postSalary;
    }

    public void setPostSalary(BigDecimal postSalary) {
        this.postSalary = postSalary;
    }
    public BigDecimal getLevelSalary() {
        return levelSalary;
    }

    public void setLevelSalary(BigDecimal levelSalary) {
        this.levelSalary = levelSalary;
    }
    public BigDecimal getEducatedSalary() {
        return educatedSalary;
    }

    public void setEducatedSalary(BigDecimal educatedSalary) {
        this.educatedSalary = educatedSalary;
    }
    public BigDecimal getSportSalary() {
        return sportSalary;
    }

    public void setSportSalary(BigDecimal sportSalary) {
        this.sportSalary = sportSalary;
    }
    public BigDecimal getYearSalary() {
        return yearSalary;
    }

    public void setYearSalary(BigDecimal yearSalary) {
        this.yearSalary = yearSalary;
    }
    public BigDecimal getAttendanceDeduct() {
        return attendanceDeduct;
    }

    public void setAttendanceDeduct(BigDecimal attendanceDeduct) {
        this.attendanceDeduct = attendanceDeduct;
    }
    public BigDecimal getOtherPayMny() {
        return otherPayMny;
    }

    public void setOtherPayMny(BigDecimal otherPayMny) {
        this.otherPayMny = otherPayMny;
    }
    public BigDecimal getOtherDeductMny() {
        return otherDeductMny;
    }

    public void setOtherDeductMny(BigDecimal otherDeductMny) {
        this.otherDeductMny = otherDeductMny;
    }
    public BigDecimal getSalaryMny() {
        return salaryMny;
    }

    public void setSalaryMny(BigDecimal salaryMny) {
        this.salaryMny = salaryMny;
    }
    public BigDecimal getActualSalaryMny() {
        return actualSalaryMny;
    }

    public void setActualSalaryMny(BigDecimal actualSalaryMny) {
        this.actualSalaryMny = actualSalaryMny;
    }
    public BigDecimal getEndownmentPersonPercent() {
        return endownmentPersonPercent;
    }

    public void setEndownmentPersonPercent(BigDecimal endownmentPersonPercent) {
        this.endownmentPersonPercent = endownmentPersonPercent;
    }
    public BigDecimal getUnemployeePersonMny() {
        return unemployeePersonMny;
    }

    public void setUnemployeePersonMny(BigDecimal unemployeePersonMny) {
        this.unemployeePersonMny = unemployeePersonMny;
    }
    public BigDecimal getBaseMedicalPersonMny() {
        return baseMedicalPersonMny;
    }

    public void setBaseMedicalPersonMny(BigDecimal baseMedicalPersonMny) {
        this.baseMedicalPersonMny = baseMedicalPersonMny;
    }
    public Integer getRank() {
        return rank;
    }

    public void setRank(Integer rank) {
        this.rank = rank;
    }
    public String getRankName() {
        return rankName;
    }

    public void setRankName(String rankName) {
        this.rankName = rankName;
    }
    public Date getIntoDate() {
        return intoDate;
    }

    public void setIntoDate(Date intoDate) {
        this.intoDate = intoDate;
    }
    public Date getFormalDate() {
        return formalDate;
    }

    public void setFormalDate(Date formalDate) {
        this.formalDate = formalDate;
    }
    public Date getPayrollDate() {
        return payrollDate;
    }

    public void setPayrollDate(Date payrollDate) {
        this.payrollDate = payrollDate;
    }
    public String getDetailMemo() {
        return detailMemo;
    }

    public void setDetailMemo(String detailMemo) {
        this.detailMemo = detailMemo;
    }
    
}

==> ejc-bfyjerp-api-3.0.0-20250829.015648-290-sources.jar: com/ejianc/business/oa/vo/PayrollDetailVO.java <==
package com.ejianc.business.oa.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 人力行政-工资表子表
 * 
 * @author generator
 * 
 */
public class PayrollDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long payrollId; // 工资表主表id
    private Long deptId; // 部门ID
    private String deptName; // 部门
    private Long postId; // 岗位ID
    private String postName; // 岗位
    private Long sourceId; // 来源id
    private Long employeeId; // 员工名称
    private String name; // 姓名
    private String idCard; // 身份证号
    private BigDecimal salaryTime; // 计薪工时
    private BigDecimal basicSalary; // 基本薪资
    private BigDecimal postSalary; // 岗位薪资
    private BigDecimal levelSalary; // 层级薪资
    private BigDecimal educatedSalary; // 学历津贴
    private BigDecimal sportSalary; // 交通补助
    private BigDecimal yearSalary; // 司龄津贴
    private BigDecimal attendanceDeduct; // 考勤扣款
    private BigDecimal otherPayMny; // 其他应付款
    private BigDecimal otherDeductMny; // 其他扣款
    private BigDecimal salaryMny; // 应发工资
    private BigDecimal actualSalaryMny; // 实发工资
    private BigDecimal endownmentPersonMny; // 养老保险
    private BigDecimal unemployeePersonMny; // 失业保险
    private BigDecimal baseMedicalPersonMny; // 基本医疗
    private Integer rank; // 职级
    private String rankName; // 职级
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date intoDate; // 入职日期
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date formalDate; // 转正日期
    @JsonFormat(pattern = "yyyy-MM", timezone = "GMT+8")
    private Date payrollDate; // 工资单日期
    private String detailMemo; // 备注
    

    public Long getPayrollId() {
        return payrollId;
    }

    public void setPayrollId(Long payrollId) {
        this.payrollId = payrollId;
    }
    public Long getDeptId() {
        return deptId;
    }

    public void setDeptId(Long deptId) {
        this.deptId = deptId;
    }
    public String getDeptName() {
        return deptName;
    }

    public void setDeptName(String deptName) {
        this.deptName = deptName;
    }
    public Long getPostId() {
        return postId;
    }

    public void setPostId(Long postId) {
        this.postId = postId;
    }
    public String getPostName() {
        return postName;
    }

    public void setPostName(String postName) {
        this.postName = postName;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }
    public BigDecimal getSalaryTime() {
        return salaryTime;
    }

    public void setSalaryTime(BigDecimal salaryTime) {
        this.salaryTime = salaryTime;
    }
    public BigDecimal getBasicSalary() {
        return basicSalary;
    }

    public void setBasicSalary(BigDecimal basicSalary) {
        this.basicSalary = basicSalary;
    }
    public BigDecimal getPostSalary() {
        return postSalary;
    }

    public void setPostSalary(BigDecimal postSalary) {
        this.postSalary = postSalary;
    }
    public BigDecimal getLevelSalary() {
        return levelSalary;
    }

    public void setLevelSalary(BigDecimal levelSalary) {
        this.levelSalary = levelSalary;
    }
    public BigDecimal getEducatedSalary() {
        return educatedSalary;
    }

    public void setEducatedSalary(BigDecimal educatedSalary) {
        this.educatedSalary = educatedSalary;
    }
    public BigDecimal getSportSalary() {
        return sportSalary;
    }

    public void setSportSalary(BigDecimal sportSalary) {
        this.sportSalary = sportSalary;
    }
    public BigDecimal getYearSalary() {
        return yearSalary;
    }

    public void setYearSalary(BigDecimal yearSalary) {
        this.yearSalary = yearSalary;
    }
    public BigDecimal getAttendanceDeduct() {
        return attendanceDeduct;
    }

    public void setAttendanceDeduct(BigDecimal attendanceDeduct) {
        this.attendanceDeduct = attendanceDeduct;
    }
    public BigDecimal getOtherPayMny() {
        return otherPayMny;
    }

    public void setOtherPayMny(BigDecimal otherPayMny) {
        this.otherPayMny = otherPayMny;
    }
    public BigDecimal getOtherDeductMny() {
        return otherDeductMny;
    }

    public void setOtherDeductMny(BigDecimal otherDeductMny) {
        this.otherDeductMny = otherDeductMny;
    }
    public BigDecimal getSalaryMny() {
        return salaryMny;
    }

    public void setSalaryMny(BigDecimal salaryMny) {
        this.salaryMny = salaryMny;
    }
    public BigDecimal getActualSalaryMny() {
        return actualSalaryMny;
    }

    public void setActualSalaryMny(BigDecimal actualSalaryMny) {
        this.actualSalaryMny = actualSalaryMny;
    }

    public BigDecimal getEndownmentPersonMny() {
        return endownmentPersonMny;
    }

    public void setEndownmentPersonMny(BigDecimal endownmentPersonMny) {
        this.endownmentPersonMny = endownmentPersonMny;
    }

    public BigDecimal getUnemployeePersonMny() {
        return unemployeePersonMny;
    }

    public void setUnemployeePersonMny(BigDecimal unemployeePersonMny) {
        this.unemployeePersonMny = unemployeePersonMny;
    }
    public BigDecimal getBaseMedicalPersonMny() {
        return baseMedicalPersonMny;
    }

    public void setBaseMedicalPersonMny(BigDecimal baseMedicalPersonMny) {
        this.baseMedicalPersonMny = baseMedicalPersonMny;
    }
    public Integer getRank() {
        return rank;
    }

    public void setRank(Integer rank) {
        this.rank = rank;
    }
    public String getRankName() {
        return rankName;
    }

    public void setRankName(String rankName) {
        this.rankName = rankName;
    }
    public Date getIntoDate() {
        return intoDate;
    }

    public void setIntoDate(Date intoDate) {
        this.intoDate = intoDate;
    }
    public Date getFormalDate() {
        return formalDate;
    }

    public void setFormalDate(Date formalDate) {
        this.formalDate = formalDate;
    }
    public Date getPayrollDate() {
        return payrollDate;
    }

    public void setPayrollDate(Date payrollDate) {
        this.payrollDate = payrollDate;
    }
    public String getDetailMemo() {
        return detailMemo;
    }

    public void setDetailMemo(String detailMemo) {
        this.detailMemo = detailMemo;
    }
    
}
